import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { G as GetScheduleTimeFrameOptions, S as ScheduleTimeFrame, L as ListScheduleTimeFramesOptions, a as ListScheduleTimeFramesResponse, b as ScheduleTimeFrameUpdatedEnvelope } from './calendar-v3-schedule-time-frame-schedule-time-frames.universal-Bmaxv3bl.mjs';
export { H as ActionEvent, A as Address, k as AddressHint, N as BaseEventMetadata, B as BusinessSchedule, C as Categories, q as ChangeContext, r as ChangeContextPayloadOneOf, o as ConsentPolicy, D as DayOfWeek, v as DomainEvent, w as DomainEventBodyOneOf, E as Empty, x as EntityCreatedEvent, F as EntityDeletedEvent, z as EntityUpdatedEvent, O as EventMetadata, l as GeoCoordinates, d as GetScheduleTimeFrameRequest, e as GetScheduleTimeFrameResponse, J as IdentificationData, K as IdentificationDataIdOneOf, f as ListScheduleTimeFramesRequest, j as Locale, I as MessageEnvelope, M as Multilingual, P as PlacementType, i as Properties, s as PropertiesChange, R as ResolutionMethod, y as RestoreInfo, u as SiteCloned, t as SiteCreated, h as SitePropertiesEvent, g as SitePropertiesNotification, m as SpecialHourPeriod, c as Status, n as SupportedLanguage, T as TimePeriod, p as Translation, W as WebhookIdentityType, Z as ZonedDate } from './calendar-v3-schedule-time-frame-schedule-time-frames.universal-Bmaxv3bl.mjs';

declare function getScheduleTimeFrame$1(httpClient: HttpClient): GetScheduleTimeFrameSignature;
interface GetScheduleTimeFrameSignature {
    /**
     * Retrieves a schedule time frame by schedule ID.
     * @param - [Schedule](https://dev.wix.com/docs/sdk/backend-modules/calendar/schedules/introduction)
     * ID for which to retrieve the schedule time frame.
     * @returns Retrieved schedule time frame.
     */
    (_id: string, options?: GetScheduleTimeFrameOptions | undefined): Promise<ScheduleTimeFrame>;
}
declare function listScheduleTimeFrames$1(httpClient: HttpClient): ListScheduleTimeFramesSignature;
interface ListScheduleTimeFramesSignature {
    /**
     * Retrieves a list of schedule time frames by schedule IDs.
     *
     *
     * Sorted by schedule ID in ascending order.
     * @param - IDs of the schedules for which to retrieve schedule time frames.
     *
     * Min: 1 schedule ID
     * Max: 100 schedule IDs
     */
    (ids: string[], options?: ListScheduleTimeFramesOptions | undefined): Promise<ListScheduleTimeFramesResponse>;
}
declare const onScheduleTimeFrameUpdated$1: EventDefinition<ScheduleTimeFrameUpdatedEnvelope, "wix.calendar.v3.schedule_time_frame_updated">;

declare const getScheduleTimeFrame: MaybeContext<BuildRESTFunction<typeof getScheduleTimeFrame$1> & typeof getScheduleTimeFrame$1>;
declare const listScheduleTimeFrames: MaybeContext<BuildRESTFunction<typeof listScheduleTimeFrames$1> & typeof listScheduleTimeFrames$1>;
/**
 * Triggered when a schedule's time frame is updated, indicating a new first or
 * last event or a change in the recurrence period, such as an extension or
 * reduction.
 */
declare const onScheduleTimeFrameUpdated: BuildEventDefinition<typeof onScheduleTimeFrameUpdated$1>;

export { GetScheduleTimeFrameOptions, ListScheduleTimeFramesOptions, ListScheduleTimeFramesResponse, ScheduleTimeFrame, ScheduleTimeFrameUpdatedEnvelope, getScheduleTimeFrame, listScheduleTimeFrames, onScheduleTimeFrameUpdated };
